summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--crawl-ref/source/abl-show.cc10
-rw-r--r--crawl-ref/source/acr.cc2
-rw-r--r--crawl-ref/source/enum.h4
-rw-r--r--crawl-ref/source/religion.cc20
-rw-r--r--crawl-ref/source/spells1.cc67
-rw-r--r--crawl-ref/source/spells1.h6
6 files changed, 54 insertions, 55 deletions
diff --git a/crawl-ref/source/abl-show.cc b/crawl-ref/source/abl-show.cc
index b58cb00097..34ae3129c9 100644
--- a/crawl-ref/source/abl-show.cc
+++ b/crawl-ref/source/abl-show.cc
@@ -111,7 +111,7 @@ ability_type god_abilities[MAX_NUM_GODS][MAX_GOD_ABILITIES] =
{ ABIL_NON_ABILITY, ABIL_NON_ABILITY, ABIL_NON_ABILITY,
ABIL_NON_ABILITY, ABIL_NON_ABILITY },
// Zin
- { ABIL_ZIN_RECITE, ABIL_ZIN_REVITALISATION, ABIL_NON_ABILITY,
+ { ABIL_ZIN_RECITE, ABIL_ZIN_VITALISATION, ABIL_NON_ABILITY,
ABIL_NON_ABILITY, ABIL_ZIN_SANCTUARY },
// TSO
{ ABIL_NON_ABILITY, ABIL_TSO_DIVINE_SHIELD, ABIL_NON_ABILITY,
@@ -233,7 +233,7 @@ static const ability_def Ability_List[] =
// INVOCATIONS:
// Zin
{ ABIL_ZIN_RECITE, "Recite", 3, 0, 120, 0, ABFLAG_DELAY },
- { ABIL_ZIN_REVITALISATION, "Revitalisation", 0, 0, 100, 2, ABFLAG_CONF_OK },
+ { ABIL_ZIN_VITALISATION, "Vitalisation", 0, 0, 100, 2, ABFLAG_CONF_OK },
{ ABIL_ZIN_SANCTUARY, "Sanctuary", 7, 0, 150, 15, ABFLAG_NONE },
// The Shining One
@@ -673,7 +673,7 @@ static talent _get_talent(ability_type ability, bool check_confused)
failure = 40 - (you.piety / 20) - (3 * you.skills[SK_INVOCATIONS]);
break;
- case ABIL_ZIN_REVITALISATION:
+ case ABIL_ZIN_VITALISATION:
case ABIL_TSO_DIVINE_SHIELD:
case ABIL_BEOGH_SMITING:
case ABIL_MAKHLEB_MINOR_DESTRUCTION:
@@ -1370,9 +1370,9 @@ static bool _do_ability(const ability_def& abil)
break;
}
- case ABIL_ZIN_REVITALISATION:
+ case ABIL_ZIN_VITALISATION:
{
- int result = cast_revitalisation(1 + (you.skills[SK_INVOCATIONS] / 4));
+ int result = cast_vitalisation(1 + (you.skills[SK_INVOCATIONS] / 4));
if (result > 0)
exercise(SK_INVOCATIONS, 2 + random2(result));
break;
diff --git a/crawl-ref/source/acr.cc b/crawl-ref/source/acr.cc
index b322622834..32d118f992 100644
--- a/crawl-ref/source/acr.cc
+++ b/crawl-ref/source/acr.cc
@@ -3063,7 +3063,7 @@ static void _decrement_durations()
}
}
- reduce_revitalisation_chain(1);
+ reduce_vitalisation_chain(1);
if (_decrement_a_duration(DUR_DIVINE_ROBUSTNESS))
remove_divine_robustness();
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 07db487814..7abdfa5d21 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -75,7 +75,7 @@ enum ability_type
// Divine abilities
ABIL_ZIN_RECITE = 110, // 110
- ABIL_ZIN_REVITALISATION,
+ ABIL_ZIN_VITALISATION,
ABIL_ZIN_SANCTUARY,
ABIL_TSO_DIVINE_SHIELD = 120, // 120
ABIL_TSO_CLEANSING_FLAME,
@@ -1105,7 +1105,7 @@ enum duration_type
DUR_SLEEP,
DUR_SAGE,
DUR_TELEPATHY,
- DUR_REVITALISATION_CHAIN,
+ DUR_VITALISATION_CHAIN,
NUM_DURATIONS
};
diff --git a/crawl-ref/source/spells1.h b/crawl-ref/source/spells1.h
index e95537b97e..7e88df47fa 100644
--- a/crawl-ref/source/spells1.h
+++ b/crawl-ref/source/spells1.h
@@ -55,11 +55,11 @@ char cast_lesser_healing(void);
* *********************************************************************** */
int cast_healing(int pow, int target_x = -1, int target_y = -1);
-void revitalisation_chain(int amount);
-void reduce_revitalisation_chain(int amount);
+void vitalisation_chain(int amount);
+void reduce_vitalisation_chain(int amount);
void remove_divine_robustness();
void remove_divine_stamina();
-int cast_revitalisation(int pow);
+int cast_vitalisation(int pow);
// last updated 24may2000 {dlb}
/* ***********************************************************************
diff --git a/crawl-ref/source/religion.cc b/crawl-ref/source/religion.cc
index 054adedde8..52da4191de 100644
--- a/crawl-ref/source/religion.cc
+++ b/crawl-ref/source/religion.cc
@@ -203,7 +203,7 @@ const char* god_gain_power_messages[NUM_GODS][MAX_GOD_ABILITIES] =
{ "", "", "", "", "" },
// Zin
{ "recite Zin's Axioms of Law",
- "call upon Zin for revitalisation",
+ "call upon Zin for vitalisation",
"",
"",
"call upon Zin to create a sanctuary" },
@@ -289,7 +289,7 @@ const char* god_lose_power_messages[NUM_GODS][MAX_GOD_ABILITIES] =
{ "", "", "", "", "" },
// Zin
{ "recite Zin's Axioms of Law",
- "call upon Zin for revitalisation",
+ "call upon Zin for vitalisation",
"",
"",
"call upon Zin to create a sanctuary" },
@@ -475,14 +475,14 @@ static void _inc_penance(god_type god, int val)
// orcish bonuses don't apply under penance
if (god == GOD_BEOGH)
you.redraw_armour_class = true;
// neither does Zin's revitalisation chaining, divine
// robustness, or divine stamina
else if (god == GOD_ZIN)
{
- if (you.duration[DUR_REVITALISATION_CHAIN])
+ if (you.duration[DUR_VITALISATION_CHAIN])
{
- mpr("Your power of revitalisation disappears!");
- you.duration[DUR_REVITALISATION_CHAIN] = 0;
+ mpr("Your power of vitalisation disappears!");
+ you.duration[DUR_VITALISATION_CHAIN] = 0;
}
if (you.duration[DUR_DIVINE_ROBUSTNESS])
@@ -4349,10 +4349,10 @@ void excommunication(god_type new_god)
break;
case GOD_ZIN:
- if (you.duration[DUR_REVITALISATION_CHAIN])
+ if (you.duration[DUR_VITALISATION_CHAIN])
{
- mpr("Your power of revitalisation disappears!");
- you.duration[DUR_REVITALISATION_CHAIN] = 0;
+ mpr("Your power of vitalisation disappears!");
+ you.duration[DUR_VITALISATION_CHAIN] = 0;
}
if (you.duration[DUR_DIVINE_ROBUSTNESS])
@@ -475,14 +475,14 @@ static void _inc_penance(god_type god, int val)
if (god == GOD_BEOGH)
you.redraw_armour_class = true;
- // neither does Zin's revitalisation chaining, divine
- // robustness, or divine stamina
+ // neither does Zin's vitalisation chaining, divine robustness,
+ // or divine stamina
else if (god == GOD_ZIN)
{
diff --git a/crawl-ref/source/spells1.cc b/crawl-ref/source/spells1.cc
index 312e2a17d6..a46c3da0f1 100644
--- a/crawl-ref/source/spells1.cc
+++ b/crawl-ref/source/spells1.cc
@@ -760,32 +760,32 @@ int cast_healing( int pow, int target_x, int target_y )
return (_healing_spell( pow + roll_dice( 2, pow ) - 2, target_x, target_y ));
}
-void revitalisation_chain(int amount)
+void vitalisation_chain(int amount)
{
if (amount <= 0)
return;
- const int old_value = you.duration[DUR_REVITALISATION_CHAIN];
- you.duration[DUR_REVITALISATION_CHAIN] += amount;
+ const int old_value = you.duration[DUR_VITALISATION_CHAIN];
+ you.duration[DUR_VITALISATION_CHAIN] += amount;
- if (you.duration[DUR_REVITALISATION_CHAIN] > 30)
- you.duration[DUR_REVITALISATION_CHAIN] = 30;
+ if (you.duration[DUR_VITALISATION_CHAIN] > 30)
+ you.duration[DUR_VITALISATION_CHAIN] = 30;
if (old_value == 0)
- mpr("Zin amplifies your power of revitalisation!", MSGCH_DURATION);
+ mpr("Zin amplifies your power of vitalisation!", MSGCH_DURATION);
}
-void reduce_revitalisation_chain(int amount)
+void reduce_vitalisation_chain(int amount)
{
- if (you.duration[DUR_REVITALISATION_CHAIN] == 0 || amount <= 0)
+ if (you.duration[DUR_VITALISATION_CHAIN] == 0 || amount <= 0)
return;
- you.duration[DUR_REVITALISATION_CHAIN] -= amount;
+ you.duration[DUR_VITALISATION_CHAIN] -= amount;
- if (you.duration[DUR_REVITALISATION_CHAIN] <= 0)
+ if (you.duration[DUR_VITALISATION_CHAIN] <= 0)
{
- you.duration[DUR_REVITALISATION_CHAIN] = 0;
- mpr("Your power of revitalisation returns to normal.", MSGCH_DURATION);
+ you.duration[DUR_VITALISATION_CHAIN] = 0;
+ mpr("Your power of vitalisation returns to normal.", MSGCH_DURATION);
}
}
@@ -809,7 +809,7 @@ void remove_divine_stamina()
you.attribute[ATTR_DIVINE_STAMINA] = 0;
}
-int cast_revitalisation(int pow)
+int cast_vitalisation(int pow)
{
const int step_max_chain = 6;
const int type_max_chain = 4;
@@ -821,9 +821,8 @@ int cast_revitalisation(int pow)
static int mp_amt;
static bool need_chain;
- // If revitalisation chaining is turned off, start from the
- // beginning.
- if (you.duration[DUR_REVITALISATION_CHAIN] == 0)
+ // If vitalisation chaining is turned off, start from the beginning.
+ if (you.duration[DUR_VITALISATION_CHAIN] == 0)
{
step = 0;
step_max = std::min(pow, step_max_chain);
@@ -895,7 +894,7 @@ int cast_revitalisation(int pow)
case 3:
case 4:
case 5:
- if ((step == 3 || you.duration[DUR_REVITALISATION_CHAIN] > 0)
+ if ((step == 3 || you.duration[DUR_VITALISATION_CHAIN] > 0)
&& you.attribute[ATTR_DIVINE_ROBUSTNESS] == (step - 3)
&& player_mutation_level(MUT_ROBUST) < (6 - step))
{
@@ -930,8 +929,8 @@ int cast_revitalisation(int pow)
need_chain = false;
step = 0;
type = 1;
// Deliberate fall through, resetting the revitalisation
// chaining indicator and the step counter.
case 1:
// Restore HP.
@@ -947,8 +946,8 @@ int cast_revitalisation(int pow)
need_chain = false;
step = 0;
type = 2;
// Deliberate fall through, resetting the revitalisation
// chaining indicator and the step counter.
case 2:
// Restore MP.
@@ -964,8 +963,8 @@ int cast_revitalisation(int pow)
need_chain = false;
step = 0;
type = 3;
// Deliberate fall through, resetting the revitalisation
// chaining indicator and the step counter.
case 3:
// Restore stats and/or add divine stamina.
@@ -997,7 +996,7 @@ int cast_revitalisation(int pow)
case 3:
case 4:
case 5:
- if ((step == 3 || you.duration[DUR_REVITALISATION_CHAIN] > 0)
+ if ((step == 3 || you.duration[DUR_VITALISATION_CHAIN] > 0)
&& you.attribute[ATTR_DIVINE_STAMINA] == (step - 3)
&& player_mutation_level(MUT_STRONG) < (17 - step)
&& player_mutation_level(MUT_CLEVER) < (17 - step)
@@ -1036,8 +1035,8 @@ int cast_revitalisation(int pow)
need_chain = false;
step = 0;
type = 4;
// Deliberate fall through, resetting the revitalisation
// chaining indicator and the step counter.
default:
// Do nothing.
@@ -1046,11 +1045,11 @@ int cast_revitalisation(int pow)
#ifdef DEBUG_DIAGNOSTICS
mprf(MSGCH_DIAGNOSTICS,
- "revitalising: step = %d, type = %d, step_max = %d",
+ "vitalising: step = %d, type = %d, step_max = %d",
step, type, step_max);
#endif
// If revitalisation has succeeded, display an appropriate message.
if (success)
{
mprf("You feel %s %s.", (step == 0) ? "only nominally" :
@@ -1077,14 +1076,14 @@ int cast_revitalisation(int pow)
else
canned_msg(MSG_NOTHING_HAPPENS);
// If revitalisation has succeeded, it hasn't succeeded as far
// as possible, and revitalisation chaining is needed, turn on
// revitalisation chaining for several turns.
if (success && step < step_max && need_chain)
- revitalisation_chain(6);
- // Otherwise, turn off revitalisation chaining.
+ vitalisation_chain(6);
+ // Otherwise, turn off vitalisation chaining.
else
- reduce_revitalisation_chain(30);
+ reduce_vitalisation_chain(30);
return (success) ? (step + 1) : 0;
}
@@ -930,8 +929,8 @@ int cast_revitalisation(int pow)
step = 0;
type = 1;
- // Deliberate fall through, resetting the revitalisation
- // chaining indicator and the step counter.
+ // Deliberate fall through, resetting the vitalisation chaining
+ // indicator and the step counter.
case 1:
// Restore HP.
@@ -947,8 +946,8 @@ int cast_revitalisation(int pow)
step = 0;
type = 2;
- // Deliberate fall through, resetting the revitalisation
- // chaining indicator and the step counter.
+ // Deliberate fall through, resetting the vitalisation chaining
+ // indicator and the step counter.
case 2:
// Restore MP.
@@ -964,8 +963,8 @@ int cast_revitalisation(int pow)
step = 0;
type = 3;
- // Deliberate fall through, resetting the revitalisation
- // chaining indicator and the step counter.
+ // Deliberate fall through, resetting the vitalisation chaining
+ // indicator and the step counter.
case 3:
// Restore stats and/or add divine stamina.
@@ -1036,8 +1035,8 @@ int cast_revitalisation(int pow)
step = 0;
type = 4;
- // Deliberate fall through, resetting the revitalisation
- // chaining indicator and the step counter.
+ // Deliberate fall through, resetting the vitalisation chaining
+ // indicator and the step counter.
default:
// Do nothing.
@@ -1046,11 +1045,11 @@ int cast_revitalisation(int pow)
step, type, step_max);
#endif
- // If revitalisation has succeeded, display an appropriate message.
+ // If vitalisation has succeeded, display an appropriate message.
if (success)
{
@@ -1077,14 +1076,14 @@ int cast_revitalisation(int pow)
else
canned_msg(MSG_NOTHING_HAPPENS);
- // If revitalisation has succeeded, it hasn't succeeded as far
- // as possible, and revitalisation chaining is needed, turn on
- // revitalisation chaining for several turns.
+ // If vitalisation has succeeded, it hasn't succeeded as far as
+ // possible, and vitalisation chaining is needed, turn on
+ // vitalisation chaining for several turns.
if (success && step < step_max && need_chain)